--[[ =================================================================
    Description:
        All globals used within UberInventory.
    ================================================================= --]]

-- Colors used within UberInventory
    C_GOLD   = "|cFFFFD700";
    C_SILVER = "|cFFC7C7CF";
    C_COPPER = "|cFFEDA55F";
    C_GREEN  = "|cFF00FF00";
    C_WHITE  = "|cFFFFFFFF";
    C_BLUE   = "|cFF3366FF";
    C_RED    = "|cFFFF5533";
    C_YELLOW = "|cFFFFFF00";
    C_GREY   = "|cFFAAAAAA";
    C_CLOSE  = "|r";

-- Image path
    UBI_IMG_PATH = "Interface\\AddOns\\UberInventory\\";

-- Coin textures
    UBI_GOLD_ICON = "|T"..UBI_IMG_PATH.."gold:0|t";
    UBI_SILVER_ICON = "|T"..UBI_IMG_PATH.."silver:0|t";
    UBI_COPPER_ICON = "|T"..UBI_IMG_PATH.."copper:0|t";

-- Events tracked by UBI
    UBI_TRACKED_EVENTS = { -- Startup events
                           "VARIABLES_LOADED",

                           -- Bag events
                           "BAG_UPDATE",

                           -- Character event (equipped items)
                           "UNIT_INVENTORY_CHANGED",

                           -- Bank events
                           "BANKFRAME_OPENED",
                           "BANKFRAME_CLOSED",
                           "PLAYERBANKSLOTS_CHANGED",
                           "PLAYERBANKBAGSLOTS_CHANGED",

                           -- Guildbank events
                           "GUILDBANKFRAME_OPENED",
                           "GUILDBANKFRAME_CLOSED",
                           "GUILDBANKBAGSLOTS_CHANGED",
                           "GUILDBANK_UPDATE_TABS",
                           "GUILDBANK_UPDATE_MONEY",

                           -- Mailbox events
                           "MAIL_SHOW",
                           "MAIL_CLOSED",
                           "MAIL_INBOX_UPDATE",
                           "UPDATE_PENDING_MAIL",

                           -- Player events
                           "PLAYER_MONEY",
                           "PLAYER_ENTERING_WORLD",
                           "PLAYER_LEAVING_WORLD",

                           -- Guild changes
                           "PLAYER_GUILD_UPDATE",

                           -- Chat events
                           "CHAT_MSG_ADDON"
                         };

-- Drop rates
    UBI_Droprates = { "1%-2%" ,    -- Extremely low
                      "3%-14%" ,   -- Very low
                      "15%-24%" ,  -- Low
                      "25%-50%" ,  -- Medium
                      "51%-99%" ,  -- High
                      "100%" };    -- Guaranteed

-- Global variables
    UBI = _G["UBI"]; -- AddOn object itself
    UBI_NAME = GetAddOnMetadata( "UberInventory", "Title" );
    UBI_VERSION = GetAddOnMetadata( "UberInventory", "Version" );
    UBI_NAME_VERSION = UBI_NAME.." - "..UBI_VERSION;
    UBI_WEBSITE = C_BLUE.."http://redeye.xs4all.nl/ubi/"..C_WHITE;
    UBI_REALM = GetRealmName();
    UBI_PLAYER = UnitName( "player" );
    UBI_PLAYER_CLASS = UnitClass( "player" );
    UBI_PLAYER_RACE = UnitRace( "player" );
    UBI_GUILD = nil;
    UBI_FACTION = UnitFactionGroup( "player" );
    UBI_EMPTY_TEXT = "---";
    UBI_BANK_OPEN = false;             -- Is the bank framed open?
    UBI_MAILBOX_OPEN = false;          -- Is the mailbox frame open?
    UBI_GUILDBANK_OPEN = false;        -- Is the guildbank frame open?
    UBI_GUILDBANK_VIEWACCESS = true;   -- View access to all guildbank tabs?
    UBI_SEC_IN_DAY = 60 * 60 * 24;     -- The number of seconds in a day
    UBI_VERSION_WARNING = false;       -- Received version warning
    UBI_TooltipItem = nil;             -- Filled from main inventory frame (used to show correct counts when showing alt information)
    UBI_TooltipLocation = nil;         -- Filled from main inventory frame (used to hide alt if the alt is viewed)
    UBI_CHECK_DATE = date( "%Y%m%d" ); -- Date when last daily check has been performed

-- Alts and Guildbanks
    UBI_Characters = {};               -- Used for list of alt characters
    UBI_Guildbanks = {};               -- Used for list of guildbanks
    UBI_LocationList = {};             -- Used to track all locations combined
    UBI_LocationCounter = 0;           -- Used to track the number of items in location dropdownbox

-- Globals for receiving guildbank data
    UBI_GBData = {};                   -- Array for receiving guildbank data through the guild chat channel
    UBI_GBSender = nil;                -- Who is sending guildbank data (only the latest player is tracked)

-- Days between collection events before message is displayed to visit mailbox, bank or guildbank
    UBI_MAILBOX_VISIT_INTERVAL = 21;   -- in days
    UBI_BANK_VISIT_INTERVAL = 30;      -- in days
    UBI_GUILDBANK_VISIT_INTERVAL = 14; -- in days

-- When should expiring mail be reported
    UBI_MAIL_EXPIRE_WARNING = 5;       -- in days
    UBI_MAIL_MAX = 50;                 -- Maximum number of mails fetched from server
    UBI_MAIL_WARNING = false;          -- Mail warning already sent

-- Filter settings
    UBI_FILTER_TEXT = "";              -- Default no search string
    UBI_FILTER_LOCATIONS = 2;          -- Default all items
    UBI_FILTER_QUALITY = 1;            -- Default all qualities
    UBI_FILTER_CLASSES = 1;            -- Default all classes
    UBI_FILTER_SUBCLASSES = 0;         -- Default no subclass
    UBI_FILTER_USABLE = false;         -- Only show usable items
    UBI_SCAN_DATE = time();            -- Latest inventory scan
    UBI_Filter = { text = nil,
                   location = nil,
                   quality = nil,
                   class = nil,
                   subclass = nil,
                   usable = nil,
                   date = nil }; -- Track current search settings

-- Scrolling variables
    UBI_PAGE = 0;                      -- Starting page
    UBI_PIX_PER_PAGE = 0;              -- Pixels per page (related to height of scrollbar, calculated as (height-32)/2, done in the XML document)
    UBI_SCROLLBAR = nil;               -- ScrollFrame object

-- Equip slots
    UBI_EQUIP_SLOTS = { "HeadSlot",
                        "NeckSlot",
                        "ShoulderSlot",
                        "BackSlot",
                        "ChestSlot",
                        "ShirtSlot",
                        "TabardSlot",
                        "WristSlot",
                        "HandsSlot",
                        "WaistSlot",
                        "LegsSlot",
                        "FeetSlot",
                        "Finger0Slot",
                        "Finger1Slot",
                        "Trinket0Slot",
                        "Trinket1Slot",
                        "MainHandSlot",
                        "SecondaryHandSlot",
                        "RangedSlot" }; -- AmmoSlot is excluded, counts as 1 regardless number of arrows. bullets are linked

-- Quality names (using Blizzards localized strings) and colors
    UBI_QUALITY = { ITEM_QUALITY0_DESC,
                    ITEM_QUALITY1_DESC,
                    ITEM_QUALITY2_DESC,
                    ITEM_QUALITY3_DESC,
                    ITEM_QUALITY4_DESC,
                    ITEM_QUALITY5_DESC,
                    ITEM_QUALITY6_DESC };

-- Location texture (Guildbank image dynamic based on faction)
    UBI_LOCATION_TEXTURE = { UBI_IMG_PATH.."bag",
                             UBI_IMG_PATH.."bank",
                             UBI_IMG_PATH.."key",
                             UBI_IMG_PATH.."mail",
                             UBI_IMG_PATH.."equipped",
                             UBI_IMG_PATH..string.lower( UBI_FACTION ) };

-- Frame/tooltip related options
    UBI_NUM_ITEMBUTTONS = 16;
    UBI_MAX_RECIPE_INFO = 10;

-- Saved variable
    UBI_Data = {}; -- Main data structure for UberInventory (items, prices, options)

-- Inventory items (Sorted and filtered)
    UBI_Sorted = {};
    UBI_Track = {};
    UBI_Inventory_count = 0;
    UBI_Items_Work = {};

-- Tooltip hook related stuff
    currentItemCount = 0;
    currentItemId = nil;
    UBI_Hooks = {};
    UBI_Hooks["OnTooltipSetItem"] = {};
    UBI_Hooks["OnTooltipCleared"] = {};

-- Performance related options
    UBI_DISP_COUNT = 0;

-- Pattern for detecting 'Sales Pending'-mails
    UBI_SALES_PENDING = gsub(AUCTION_INVOICE_MAIL_SUBJECT, "%%s", ".*");